
# -*- coding: utf-8 -*-
"""
Created on Fri Feb 18 11:05:22 2022

@author: pwiechen
"""

#%%
import numpy as np   
import pandas as pd       
import matplotlib.pyplot as plt     
import os
from scipy.interpolate import interp1d

dir_path = os.path.dirname(os.path.abspath(__file__))
os.chdir(dir_path)

print(dir_path)

from ch0_functions import *
from ch0_rotation_matrix import *

#%% Dune coordinates

# Dune 1 coordinates

x_extension_seaward = 450
x_extension_landward = 50
amount_of_grid_points = 10*(x_extension_seaward +  x_extension_landward)

origin_dune_1 = (72314.8, 451899)
orientation_dune_1 = 7*np.pi/2 - 296*np.pi/180

x_cross_dune_1 = np.linspace(origin_dune_1[0]-x_extension_seaward*np.cos(orientation_dune_1), origin_dune_1[0]+x_extension_landward*np.cos(orientation_dune_1), amount_of_grid_points)
y_cross_dune_1 = origin_dune_1[1] + np.tan(orientation_dune_1)*(x_cross_dune_1 - origin_dune_1[0])
cross_1d_dune_1 = np.linspace(-x_extension_seaward, x_extension_landward, len(x_cross_dune_1))

# Dune 2 coordinates

origin_dune_2 = (72587.6, 452348)
orientation_dune_2 = 7*np.pi/2 - 310*np.pi/180

x_cross_dune_2 = np.linspace(origin_dune_2[0]-x_extension_seaward*np.cos(orientation_dune_2), origin_dune_2[0]+x_extension_landward*np.cos(orientation_dune_2), amount_of_grid_points)
y_cross_dune_2 = origin_dune_2[1] + np.tan(orientation_dune_2)*(x_cross_dune_2 - origin_dune_2[0])
cross_1d_dune_2 = np.linspace(-x_extension_seaward, x_extension_landward, len(x_cross_dune_2))

#%%

types_dict = {'description': str,'date':str, 'time_raw':str, 'x_val': float, 'y_val': float, 'z_val': float, '2d_error': float, '3d_error': float}
max_error = 0.05 

# Compute cross sections of November 24
        
gps_dataset_20211124 = pd.read_csv(r'../../GPS/20211124/20211124_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211124 = gps_dataset_20211124.drop(gps_dataset_20211124[gps_dataset_20211124['3d_error'] > max_error].index)

gps_dataset_20211124_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211124, 3.50)
gps_dataset_20211124_dune_1.dropna(inplace=True)
gps_dataset_20211124_dune_2 = cross_section_1d_GPS(x_cross_dune_2, y_cross_dune_2, origin_dune_2, gps_dataset_20211124, 3.50)
gps_dataset_20211124_dune_2.dropna(inplace=True)

z_20211124_dune_1 = interp1d(gps_dataset_20211124_dune_1['cross'], gps_dataset_20211124_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)
z_20211124_dune_2 = interp1d(gps_dataset_20211124_dune_2['cross'], gps_dataset_20211124_dune_2['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_2)

# Extract x and y coordinates of S01_RBR_01 and S11_RBR_04 based on the poles to which the instruments were attached

gps_20211206 = pd.read_csv(r'../../GPS/20211206/20211206_INSTRUMENTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_20211206 = gps_20211206.drop(gps_20211206[gps_20211206['3d_error'] > max_error].index)

s01_20211206 = np.mean(gps_20211206[gps_20211206.description.str.contains('S01_POLE_TOP_01')].values[:,2:], axis=0)
s11_20211206 = np.mean(gps_20211206[gps_20211206.description.str.contains('S11_POLE_TOP_01')].values[:,2:], axis=0)

# h_bed recorded in survey 24 November

s01_h_bed_20211124 = 0.96
s11_h_bed_20211124 = 0.68

instrument_height_rbr = 0.215

s01_20211206[3], s01_20211206[4] = rotation_2d(s01_20211206[0], s01_20211206[1], alpha=-orientation_dune_1, origin=origin_dune_1)
s11_20211206[3], s11_20211206[4] = rotation_2d(s11_20211206[0], s11_20211206[1], alpha=-orientation_dune_2, origin=origin_dune_2)

print('x on November 24th S01_RBR_01:', np.round(s01_20211206[0],4))
print('y on November 24th S01_RBR_01:', np.round(s01_20211206[1],4))
print('z_top on November 24th S01_RBR_01 to be inserted in instrument heights:', np.round(s01_h_bed_20211124 + interp1d(cross_1d_dune_1, z_20211124_dune_1, kind='linear')(s01_20211206[3]) + instrument_height_rbr,4))

print('x on November 24th S11_RBR_04:', np.round(s11_20211206[0],4))
print('y on November 24th S11_RBR_04:', np.round(s11_20211206[1],4))
print('z_top on November 24th S11_RBR_04 to be inserted in instrument heights:', np.round(s11_h_bed_20211124 + interp1d(cross_1d_dune_1, z_20211124_dune_2, kind='linear')(s11_20211206[3]) + instrument_height_rbr,4))

#%%
fig, (ax1, ax2) = plt.subplots(nrows=2, sharex=True, sharey=True)

ax1.plot(cross_1d_dune_1, z_20211124_dune_1, label='Survey 2021-11-24')
ax1.scatter(s01_20211206[3],interp1d(cross_1d_dune_1, z_20211124_dune_1, kind='linear')(s01_20211206[3]), label='interpolation S01')
ax1.scatter(s01_20211206[3],interp1d(cross_1d_dune_1, z_20211124_dune_1, kind='linear')(s01_20211206[3]) + s01_h_bed_20211124 + instrument_height_rbr, label='Estimation top S01_RBR_01')

ax2.plot(cross_1d_dune_2, z_20211124_dune_2, label='Survey 2021-11-24')
ax2.scatter(s11_20211206[3],interp1d(cross_1d_dune_2, z_20211124_dune_2, kind='linear')(s11_20211206[3]), label='interpolation S11')
ax2.scatter(s11_20211206[3],interp1d(cross_1d_dune_2, z_20211124_dune_2, kind='linear')(s11_20211206[3]) + s11_h_bed_20211124 + instrument_height_rbr, label='Estimation top S11_RBR_04')

ax1.legend()
ax2.legend()
ax1.grid()
ax2.grid()
ax1.set(ylabel='Elevation [m NAP]')
ax2.set(xlabel='Cross-shore coordinate [m]', ylabel='Elevation [m NAP]')

#%%