
# -*- coding: utf-8 -*-
"""
Created on Fri Feb 18 11:05:22 2022

@author: pwiechen




The pressure sensor at S10 (S10_OSSI_06) was moved on November 30 but the movement was not logged. This script computes the vertical movement based on GPS surveys. 
"""

#%%
import numpy as np   
import pandas as pd       
import matplotlib.pyplot as plt     
import os
from scipy.interpolate import griddata, interp1d
import matplotlib.path as mpltPath

dir_path = os.path.dirname(os.path.abspath(__file__))
os.chdir(dir_path)

print(dir_path)

from ch0_functions import *
from ch0_rotation_matrix import *

#%% Dune coordinates

# Dune 1 coordinates

x_extension_seaward = 450
x_extension_landward = 50
amount_of_grid_points = 10*(x_extension_seaward +  x_extension_landward)

origin_dune_1 = (72314.8, 451899)
orientation_dune_1 = 7*np.pi/2 - 296*np.pi/180

x_cross_dune_1 = np.linspace(origin_dune_1[0]-x_extension_seaward*np.cos(orientation_dune_1), origin_dune_1[0]+x_extension_landward*np.cos(orientation_dune_1), amount_of_grid_points)
y_cross_dune_1 = origin_dune_1[1] + np.tan(orientation_dune_1)*(x_cross_dune_1 - origin_dune_1[0])
cross_1d_dune_1 = np.linspace(-x_extension_seaward, x_extension_landward, len(x_cross_dune_1))

# Dune 2 coordinates

origin_dune_2 = (72587.6, 452348)
orientation_dune_2 = 7*np.pi/2 - 310*np.pi/180

x_cross_dune_2 = np.linspace(origin_dune_2[0]-x_extension_seaward*np.cos(orientation_dune_2), origin_dune_2[0]+x_extension_landward*np.cos(orientation_dune_2), amount_of_grid_points)
y_cross_dune_2 = origin_dune_2[1] + np.tan(orientation_dune_2)*(x_cross_dune_2 - origin_dune_2[0])
cross_1d_dune_2 = np.linspace(-x_extension_seaward, x_extension_landward, len(x_cross_dune_2))

#%%

types_dict = {'description': str,'date':str, 'time_raw':str, 'x_val': float, 'y_val': float, 'z_val': float, '2d_error': float, '3d_error': float}
max_error = 0.05 

# Compute projected cross sections
        
gps_dataset_20211125 = pd.read_csv(r'../../GPS/20211125/20211125_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211125 = gps_dataset_20211125.drop(gps_dataset_20211125[gps_dataset_20211125['3d_error'] > max_error].index)
gps_dataset_20211126 = pd.read_csv(r'../../GPS/20211126/20211126_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211126 = gps_dataset_20211126.drop(gps_dataset_20211126[gps_dataset_20211126['3d_error'] > max_error].index)
gps_dataset_20211127 = pd.read_csv(r'../../GPS/20211127/20211127_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211127 = gps_dataset_20211127.drop(gps_dataset_20211127[gps_dataset_20211127['3d_error'] > max_error].index)
gps_dataset_20211128 = pd.read_csv(r'../../GPS/20211128/20211128_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211128 = gps_dataset_20211128.drop(gps_dataset_20211128[gps_dataset_20211128['3d_error'] > max_error].index)
gps_dataset_20211129 = pd.read_csv(r'../../GPS/20211129/20211129_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211129 = gps_dataset_20211129.drop(gps_dataset_20211129[gps_dataset_20211129['3d_error'] > max_error].index)
gps_dataset_20211130 = pd.read_csv(r'../../GPS/20211130/20211130_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211130 = gps_dataset_20211130.drop(gps_dataset_20211130[gps_dataset_20211130['3d_error'] > max_error].index)
gps_dataset_20211201 = pd.read_csv(r'../../GPS/20211201/20211201_0800_TRANSECTS.txt', usecols=[0,1,2,3,4,5,6,7], index_col=False,delim_whitespace=True, skipinitialspace=True, names=['description','date', 'time_raw', 'x_val', 'y_val', 'z_val', '2d_error', '3d_error'], dtype=types_dict, parse_dates={'time':['date', 'time_raw']})
gps_dataset_20211201 = gps_dataset_20211201.drop(gps_dataset_20211201[gps_dataset_20211201['3d_error'] > max_error].index)

gps_dataset_20211125_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211125, 3.50)
gps_dataset_20211125_dune_1.dropna(inplace=True)
gps_dataset_20211126_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211126, 3.50)
gps_dataset_20211126_dune_1.dropna(inplace=True)
gps_dataset_20211127_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211127, 3.50)
gps_dataset_20211127_dune_1.dropna(inplace=True)
gps_dataset_20211128_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211128, 3.50)
gps_dataset_20211128_dune_1.dropna(inplace=True)
gps_dataset_20211129_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211129, 3.50)
gps_dataset_20211129_dune_1.dropna(inplace=True)
gps_dataset_20211130_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211130, 3.50)
gps_dataset_20211130_dune_1.dropna(inplace=True)
gps_dataset_20211201_dune_1 = cross_section_1d_GPS(x_cross_dune_1, y_cross_dune_1, origin_dune_1, gps_dataset_20211201, 3.50)
gps_dataset_20211201_dune_1.dropna(inplace=True)

z_20211125_dune_1 = interp1d(gps_dataset_20211125_dune_1['cross'], gps_dataset_20211125_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)
z_20211126_dune_1 = interp1d(gps_dataset_20211126_dune_1['cross'], gps_dataset_20211126_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)
z_20211127_dune_1 = interp1d(gps_dataset_20211127_dune_1['cross'], gps_dataset_20211127_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)
z_20211128_dune_1 = interp1d(gps_dataset_20211128_dune_1['cross'], gps_dataset_20211128_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)
z_20211129_dune_1 = interp1d(gps_dataset_20211129_dune_1['cross'], gps_dataset_20211129_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)
z_20211130_dune_1 = interp1d(gps_dataset_20211130_dune_1['cross'], gps_dataset_20211130_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)
z_20211201_dune_1 = interp1d(gps_dataset_20211201_dune_1['cross'], gps_dataset_20211201_dune_1['z_val'], kind='linear', bounds_error=False, fill_value=np.nan, assume_sorted=False)(cross_1d_dune_1)

z_ossi_20211125_top = (3.193 + 3.195 + 3.190)/3
z_ossi_20211130_top = 3.5490

x_s10_ossi_06 = 0.5*(72302.0617 + 72302.1100)
y_s10_ossi_06 = 0.5*(451905.2050 + 451905.0995)

c_s10_ossi_06, l_s10_ossi_06 = rotation_2d(x_s10_ossi_06, y_s10_ossi_06, alpha=-orientation_dune_1, origin=origin_dune_1)

#%%

instrument_height_ossi = 2.54*0.145

print('h_bed_est 11-25:', np.round(100*(z_ossi_20211125_top - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211125_dune_1)], z_20211125_dune_1[~np.isnan(z_20211125_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-26:', np.round(100*(z_ossi_20211125_top - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211126_dune_1)], z_20211126_dune_1[~np.isnan(z_20211126_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-27:', np.round(100*(z_ossi_20211125_top - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211127_dune_1)], z_20211127_dune_1[~np.isnan(z_20211127_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-28:', np.round(100*(z_ossi_20211125_top - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211128_dune_1)], z_20211128_dune_1[~np.isnan(z_20211128_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-29:', np.round(100*(z_ossi_20211125_top - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211129_dune_1)], z_20211129_dune_1[~np.isnan(z_20211129_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-30:', np.round(100*(z_ossi_20211125_top + 0.13 - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211130_dune_1)], z_20211130_dune_1[~np.isnan(z_20211130_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 12-01:', np.round(100*(z_ossi_20211125_top + 0.13 - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211201_dune_1)], z_20211201_dune_1[~np.isnan(z_20211201_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))

print('h_bed_est 11-25:', np.round(100*(z_ossi_20211130_top - 0.13 - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211125_dune_1)], z_20211125_dune_1[~np.isnan(z_20211125_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-26:', np.round(100*(z_ossi_20211130_top - 0.13 - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211126_dune_1)], z_20211126_dune_1[~np.isnan(z_20211126_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-27:', np.round(100*(z_ossi_20211130_top - 0.13 - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211127_dune_1)], z_20211127_dune_1[~np.isnan(z_20211127_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-28:', np.round(100*(z_ossi_20211130_top - 0.13 - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211128_dune_1)], z_20211128_dune_1[~np.isnan(z_20211128_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-29:', np.round(100*(z_ossi_20211130_top - 0.13 - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211129_dune_1)], z_20211129_dune_1[~np.isnan(z_20211129_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 11-30:', np.round(100*(z_ossi_20211130_top - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211130_dune_1)], z_20211130_dune_1[~np.isnan(z_20211130_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))
print('h_bed_est 12-01:', np.round(100*(z_ossi_20211130_top - instrument_height_ossi - interp1d(cross_1d_dune_1[~np.isnan(z_20211201_dune_1)], z_20211201_dune_1[~np.isnan(z_20211201_dune_1)], kind='linear', fill_value='extrapolate', bounds_error=False)(c_s10_ossi_06)),1))

print('Instrument elevated on 11-30 with:',np.round((z_ossi_20211130_top - (z_ossi_20211125_top + 0.13))*100,4),'cm')


#%%

